/*
 * Copyright 2010 Mario Zechner (contact@badlogicgames.com), Nathan Sweet (admin@esotericsoftware.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package com.badlogic.gdx.scenes.scene2d.actors;

import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.scenes.scene2d.Actor;

public class Label extends Actor {
	public BitmapFont font;
	public String text;

	public Label (String name, BitmapFont font, String text) {
		super(name);
		this.font = font;
		this.text = text;				
	}

	@Override protected void draw (SpriteBatch batch, float parentAlpha) {
		font.setColor(color.r, color.g, color.b, color.a * parentAlpha);
		font.draw(batch, text, x, y);
	}

	@Override protected boolean touchDown (float x, float y, int pointer) {
		return x > 0 && y > 0 && x < font.getBounds(text).width && x < font.getLineHeight();		
	}

	@Override protected boolean touchUp (float x, float y, int pointer) {
		return x > 0 && y > 0 && x < font.getBounds(text).width && x < font.getLineHeight();		
	}

	@Override protected boolean touchDragged (float x, float y, int pointer) {
		return x > 0 && y > 0 && x < font.getBounds(text).width && x < font.getLineHeight();		
	}

	@Override public Actor hit (float x, float y) {
		 return x > 0 && y > 0 && x < font.getBounds(text).width && x < font.getLineHeight() ? this : null;		
	}
}
